@@ -4,17 +4,17 @@ import factory
 from tickets.models import Ticket, TicketComment
 
 
-class UserFactory(factory.Factory):
+class UserFactory(factory.DjangoModelFactory):
     FACTORY_FOR = User
 
     username = factory.Sequence(lambda n: "User %s" % n)
 
-class TicketFactory(factory.Factory):
+class TicketFactory(factory.DjangoModelFactory):
     FACTORY_FOR = Ticket
-    
+
     creator = factory.LazyAttribute(lambda a: UserFactory())
 
-class TicketCommentFactory(factory.Factory):
+class TicketCommentFactory(factory.DjangoModelFactory):
     FACTORY_FOR = TicketComment
 
     ticket = factory.LazyAttribute(lambda a: TicketFactory())
